# Общие импорты для всех примеров
from example.llm_config import claude_3_5_haiku  # noqa: F401
from example.llm_config import claude_3_7_sonnet  # noqa: F401
from example.llm_config import claude_opus_4  # noqa: F401
from example.llm_config import claude_sonnet_4  # noqa: F401
from example.llm_config import deepseek_chat  # noqa: F401
from example.llm_config import deepseek_reasoner  # noqa: F401
from example.llm_config import gemini_2_0_flash_001  # noqa: F401
from example.llm_config import gemini_2_5_flash  # noqa: F401
from example.llm_config import gemini_2_5_pro  # noqa: F401
from example.llm_config import giga_chat  # noqa: F401
from example.llm_config import giga_chat_2  # noqa: F401
from example.llm_config import giga_chat_2_max  # noqa: F401
from example.llm_config import giga_chat_2_pro  # noqa: F401
from example.llm_config import giga_chat_max  # noqa: F401
from example.llm_config import giga_chat_pro  # noqa: F401
from example.llm_config import gpt_4_1  # noqa: F401
from example.llm_config import gpt_4_1_mini  # noqa: F401
from example.llm_config import gpt_4_1_nano  # noqa: F401
from example.llm_config import gpt_4_5_preview  # noqa: F401
from example.llm_config import gpt_4o  # noqa: F401
from example.llm_config import gpt_4o_mini  # noqa: F401
from example.llm_config import grok_3  # noqa: F401
from example.llm_config import grok_3_fast  # noqa: F401
from example.llm_config import grok_3_mini  # noqa: F401
from example.llm_config import o3_2025_04_16  # noqa: F401
from example.llm_config import o4_mini_2025_04_16  # noqa: F401
